=======
Authors
=======


Contributors
============

List of contributors in alphabetical order.

* Alexander Bourgund
* Barbara Lechner
* Carlo Dri
* Christian Schmid
* Daniel Tiemann
* Jakob Filser
* Karl Briegel
* Mirco Panighel
* Robert Spitzenpfeil


Institutions
============

List of institutions involved, in alphabetical order.

* Catalan Institute of Nanoscience and Nanotechnology
* Consiglio Nazionale delle Ricerche
* Elettra - Sincrotrone Trieste S.C.p.A.
* Technical University of Munich
